/**
 * Utility function for retrieving the runtime configuration object.
 */
export declare function useRuntimeEnv(): {
    metadata: {
        title: string;
        description: string;
        keywords: string;
    };
    api: {
        baseUrl: string;
        hubUrl: string;
        qualityBaseUrl: string;
        similarityBaseUrl: string;
        similarityServiceName: string;
        fileUploadUrl: string;
        sparqlUrl: string;
        gazetteerBaseUrl: string;
        corsproxyApiUrl: string;
    };
    authentication: {
        login: {
            useLogin: boolean;
            loginTitle: string;
            loginURL: string;
            loginRedirectUri: string;
            logoutTitle: string;
            logoutURL: string;
            logoutRedirectUri: string;
        };
        useService: boolean;
        keycloak: {
            realm: string;
            clientId: string;
            'ssl-required': string;
            'public-client': boolean;
            'verify-token-audience': boolean;
            'use-resource-role-mappings': boolean;
            'confidential-port': number;
            url?: string | undefined;
        };
        keycloakInit: {
            onLoad: "check-sso" | "login-required";
            pkceMethod: string;
            useNone: boolean;
            adapter: string;
            checkLoginIframe: boolean;
            checkLoginIframeInterval: number;
            responseMode: "query" | "fragment" | "form_post";
            flow: "standard" | "implicit" | "hybrid";
            scope: string;
            token?: string | undefined;
            refreshToken?: string | undefined;
            idToken?: string | undefined;
            timeSkew?: number | undefined;
            redirectUri?: string | undefined;
            silentCheckSsoRedirectUri?: string | undefined;
        } & {
            [k: string]: unknown;
        };
        rtp: {
            grand_type: string;
            audience: string;
        };
        authToken: string;
        authMiddleware: {
            baseUrl: string;
            enable: boolean;
            loginRedirectUrl: string;
            logoutRedirectUrl: string;
        };
    } & {
        [k: string]: unknown;
    };
    routing: {
        routerOptions: {
            base: string;
            mode: string;
        };
        navigation: {
            showSparql: boolean;
        };
        pagination: {
            usePagination: boolean;
            usePaginationArrows: boolean;
            useItemsPerPage: boolean;
            defaultItemsPerPage: number;
            defaultItemsPerPageOptions: number[];
        };
    };
    content: {
        datasetDetails: {
            embed: {
                enable: boolean;
                defaultWidth: number;
                defaultHeight: number;
                minRange: number;
                maxRange: number;
            };
            header: {
                navigation: string;
                hidePublisher: boolean;
                hideDate: boolean;
            };
            description: {
                enableMarkdownInterpretation: boolean;
            };
            keywords: {
                showTitle: boolean;
                isVisible: boolean;
                collapsed: boolean;
            };
            dataServices: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            properties: string;
            distributions: {
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
                showValidationButton: boolean;
            };
            downloadAs: {
                url: string;
                enable: boolean;
                proxyUrl: string;
                conversionFormats: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[];
            };
            similarDatasets: {
                useSimilarDatasets: boolean;
                breakpoints: {
                    verySimilar: {
                        start: number;
                        end: number;
                    };
                    similar: {
                        start: number;
                        end: number;
                    };
                    lessSimilar: {
                        start: number;
                        end: number;
                    };
                };
            };
            pages: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            visualisations: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            isUsedBy: {
                isVisible: boolean;
            };
            relatedResources: {
                isVisible: boolean;
            };
            bulkDownload: {
                buttonPosition: string;
                MAX_FILE_TITLE_LENGTH: number;
                MAX_REQUESTS_COUNT: number;
                INTERVAL_MS: number;
                TIMEOUT_MS: number;
            };
            quality: {
                displayAll: boolean;
                numberOfDisplayedQualityDistributions: number;
                csvLinter: {
                    enable: boolean;
                    displayAll: boolean;
                    numberOfDisplayedValidationResults: number;
                };
            };
        };
        datasets: {
            useSort: boolean;
            useFeed: boolean;
            useCatalogs: boolean;
            followKeywordLinks: string;
            maxKeywordLength: number;
            facets: {
                useDatasetFacets: boolean;
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                scoringFacets: {
                    useScoringFacets: boolean;
                    defaultScoringFacets: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>;
                };
            };
        };
        catalogs: {
            useSort: boolean;
            facets: {
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                useCatalogFacets: boolean;
            };
            useCatalogCountries: boolean;
            defaultCatalogImagePath: string;
            defaultCatalogCountryID: string;
            defaultCatalogID: string;
        };
        maps: {
            options: {
                id: string;
                accessToken: string;
                attribution: string;
            };
            mapVisible: boolean;
            useAnimation: boolean;
            location: [number[], number];
            spatialType: "Point" | "Polygon";
            height: string;
            width: string;
            mapContainerId: string;
            urlTemplate: string;
            geoBoundsId: string;
            sender: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
            };
            receiver: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
                attributionPosition: "topleft" | "topright" | "bottomleft" | "bottomright";
            };
            mapStyle: {
                color: string;
                fillColor: string;
                fillOpacity: number;
                weight: number;
                radius: number;
            };
        };
        dataProviderInterface: {
            useService: boolean;
            uploadFileTypes: string[];
            enableFileUploadReplace: boolean;
            basePath: string;
            specification: "dcatap" | "dcatapde";
            annifIntegration: boolean;
            annifLinkTheme: string;
            annifLinkSubject: string;
            buttons: {
                Dataset: boolean;
                Catalogue: boolean;
            };
            doiRegistrationService: {
                persistentIdentifierType: string;
            };
        };
    };
    languages: {
        useLanguageSelector: boolean;
        locale: string;
        fallbackLocale: string;
    };
    themes: {
        header: string;
    };
    tracker: {
        isPiwikPro: boolean;
        siteId: string;
        trackerUrl: string;
    };
};
