import * as z from 'zod';
export declare const authenticationSchema: z.ZodDefault<z.ZodObject<{
    useService: z.ZodDefault<z.ZodBoolean>;
    login: z.ZodDefault<z.ZodObject<{
        useLogin: z.ZodDefault<z.ZodBoolean>;
        loginTitle: z.ZodDefault<z.ZodString>;
        loginURL: z.ZodDefault<z.ZodString>;
        loginRedirectUri: z.ZodDefault<z.ZodString>;
        logoutTitle: z.ZodDefault<z.ZodString>;
        logoutURL: z.ZodDefault<z.ZodString>;
        logoutRedirectUri: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        useLogin: boolean;
        loginTitle: string;
        loginURL: string;
        loginRedirectUri: string;
        logoutTitle: string;
        logoutURL: string;
        logoutRedirectUri: string;
    }, {
        useLogin?: boolean | undefined;
        loginTitle?: string | undefined;
        loginURL?: string | undefined;
        loginRedirectUri?: string | undefined;
        logoutTitle?: string | undefined;
        logoutURL?: string | undefined;
        logoutRedirectUri?: string | undefined;
    }>>;
    keycloak: z.ZodDefault<z.ZodObject<{
        realm: z.ZodDefault<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        clientId: z.ZodDefault<z.ZodString>;
        'ssl-required': z.ZodDefault<z.ZodString>;
        'public-client': z.ZodDefault<z.ZodBoolean>;
        'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
        'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
        'confidential-port': z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        realm: string;
        clientId: string;
        'ssl-required': string;
        'public-client': boolean;
        'verify-token-audience': boolean;
        'use-resource-role-mappings': boolean;
        'confidential-port': number;
        url?: string | undefined;
    }, {
        realm?: string | undefined;
        url?: string | undefined;
        clientId?: string | undefined;
        'ssl-required'?: string | undefined;
        'public-client'?: boolean | undefined;
        'verify-token-audience'?: boolean | undefined;
        'use-resource-role-mappings'?: boolean | undefined;
        'confidential-port'?: number | undefined;
    }>>;
    keycloakInit: z.ZodDefault<z.ZodObject<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">>>;
    rtp: z.ZodDefault<z.ZodObject<{
        grand_type: z.ZodDefault<z.ZodString>;
        audience: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        grand_type: string;
        audience: string;
    }, {
        grand_type?: string | undefined;
        audience?: string | undefined;
    }>>;
    authToken: z.ZodDefault<z.ZodString>;
    authMiddleware: z.ZodDefault<z.ZodObject<{
        enable: z.ZodDefault<z.ZodBoolean>;
        baseUrl: z.ZodDefault<z.ZodString>;
        loginRedirectUrl: z.ZodDefault<z.ZodString>;
        logoutRedirectUrl: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        baseUrl: string;
        enable: boolean;
        loginRedirectUrl: string;
        logoutRedirectUrl: string;
    }, {
        baseUrl?: string | undefined;
        enable?: boolean | undefined;
        loginRedirectUrl?: string | undefined;
        logoutRedirectUrl?: string | undefined;
    }>>;
}, "passthrough", z.ZodTypeAny, z.objectOutputType<{
    useService: z.ZodDefault<z.ZodBoolean>;
    login: z.ZodDefault<z.ZodObject<{
        useLogin: z.ZodDefault<z.ZodBoolean>;
        loginTitle: z.ZodDefault<z.ZodString>;
        loginURL: z.ZodDefault<z.ZodString>;
        loginRedirectUri: z.ZodDefault<z.ZodString>;
        logoutTitle: z.ZodDefault<z.ZodString>;
        logoutURL: z.ZodDefault<z.ZodString>;
        logoutRedirectUri: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        useLogin: boolean;
        loginTitle: string;
        loginURL: string;
        loginRedirectUri: string;
        logoutTitle: string;
        logoutURL: string;
        logoutRedirectUri: string;
    }, {
        useLogin?: boolean | undefined;
        loginTitle?: string | undefined;
        loginURL?: string | undefined;
        loginRedirectUri?: string | undefined;
        logoutTitle?: string | undefined;
        logoutURL?: string | undefined;
        logoutRedirectUri?: string | undefined;
    }>>;
    keycloak: z.ZodDefault<z.ZodObject<{
        realm: z.ZodDefault<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        clientId: z.ZodDefault<z.ZodString>;
        'ssl-required': z.ZodDefault<z.ZodString>;
        'public-client': z.ZodDefault<z.ZodBoolean>;
        'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
        'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
        'confidential-port': z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        realm: string;
        clientId: string;
        'ssl-required': string;
        'public-client': boolean;
        'verify-token-audience': boolean;
        'use-resource-role-mappings': boolean;
        'confidential-port': number;
        url?: string | undefined;
    }, {
        realm?: string | undefined;
        url?: string | undefined;
        clientId?: string | undefined;
        'ssl-required'?: string | undefined;
        'public-client'?: boolean | undefined;
        'verify-token-audience'?: boolean | undefined;
        'use-resource-role-mappings'?: boolean | undefined;
        'confidential-port'?: number | undefined;
    }>>;
    keycloakInit: z.ZodDefault<z.ZodObject<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">>>;
    rtp: z.ZodDefault<z.ZodObject<{
        grand_type: z.ZodDefault<z.ZodString>;
        audience: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        grand_type: string;
        audience: string;
    }, {
        grand_type?: string | undefined;
        audience?: string | undefined;
    }>>;
    authToken: z.ZodDefault<z.ZodString>;
    authMiddleware: z.ZodDefault<z.ZodObject<{
        enable: z.ZodDefault<z.ZodBoolean>;
        baseUrl: z.ZodDefault<z.ZodString>;
        loginRedirectUrl: z.ZodDefault<z.ZodString>;
        logoutRedirectUrl: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        baseUrl: string;
        enable: boolean;
        loginRedirectUrl: string;
        logoutRedirectUrl: string;
    }, {
        baseUrl?: string | undefined;
        enable?: boolean | undefined;
        loginRedirectUrl?: string | undefined;
        logoutRedirectUrl?: string | undefined;
    }>>;
}, z.ZodTypeAny, "passthrough">, z.objectInputType<{
    useService: z.ZodDefault<z.ZodBoolean>;
    login: z.ZodDefault<z.ZodObject<{
        useLogin: z.ZodDefault<z.ZodBoolean>;
        loginTitle: z.ZodDefault<z.ZodString>;
        loginURL: z.ZodDefault<z.ZodString>;
        loginRedirectUri: z.ZodDefault<z.ZodString>;
        logoutTitle: z.ZodDefault<z.ZodString>;
        logoutURL: z.ZodDefault<z.ZodString>;
        logoutRedirectUri: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        useLogin: boolean;
        loginTitle: string;
        loginURL: string;
        loginRedirectUri: string;
        logoutTitle: string;
        logoutURL: string;
        logoutRedirectUri: string;
    }, {
        useLogin?: boolean | undefined;
        loginTitle?: string | undefined;
        loginURL?: string | undefined;
        loginRedirectUri?: string | undefined;
        logoutTitle?: string | undefined;
        logoutURL?: string | undefined;
        logoutRedirectUri?: string | undefined;
    }>>;
    keycloak: z.ZodDefault<z.ZodObject<{
        realm: z.ZodDefault<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        clientId: z.ZodDefault<z.ZodString>;
        'ssl-required': z.ZodDefault<z.ZodString>;
        'public-client': z.ZodDefault<z.ZodBoolean>;
        'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
        'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
        'confidential-port': z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        realm: string;
        clientId: string;
        'ssl-required': string;
        'public-client': boolean;
        'verify-token-audience': boolean;
        'use-resource-role-mappings': boolean;
        'confidential-port': number;
        url?: string | undefined;
    }, {
        realm?: string | undefined;
        url?: string | undefined;
        clientId?: string | undefined;
        'ssl-required'?: string | undefined;
        'public-client'?: boolean | undefined;
        'verify-token-audience'?: boolean | undefined;
        'use-resource-role-mappings'?: boolean | undefined;
        'confidential-port'?: number | undefined;
    }>>;
    keycloakInit: z.ZodDefault<z.ZodObject<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
        pkceMethod: z.ZodDefault<z.ZodString>;
        useNone: z.ZodDefault<z.ZodBoolean>;
        adapter: z.ZodDefault<z.ZodString>;
        onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
        token: z.ZodOptional<z.ZodString>;
        refreshToken: z.ZodOptional<z.ZodString>;
        idToken: z.ZodOptional<z.ZodString>;
        timeSkew: z.ZodOptional<z.ZodNumber>;
        checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
        checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
        responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
        flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
        scope: z.ZodDefault<z.ZodString>;
        redirectUri: z.ZodOptional<z.ZodString>;
        silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">>>;
    rtp: z.ZodDefault<z.ZodObject<{
        grand_type: z.ZodDefault<z.ZodString>;
        audience: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        grand_type: string;
        audience: string;
    }, {
        grand_type?: string | undefined;
        audience?: string | undefined;
    }>>;
    authToken: z.ZodDefault<z.ZodString>;
    authMiddleware: z.ZodDefault<z.ZodObject<{
        enable: z.ZodDefault<z.ZodBoolean>;
        baseUrl: z.ZodDefault<z.ZodString>;
        loginRedirectUrl: z.ZodDefault<z.ZodString>;
        logoutRedirectUrl: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        baseUrl: string;
        enable: boolean;
        loginRedirectUrl: string;
        logoutRedirectUrl: string;
    }, {
        baseUrl?: string | undefined;
        enable?: boolean | undefined;
        loginRedirectUrl?: string | undefined;
        logoutRedirectUrl?: string | undefined;
    }>>;
}, z.ZodTypeAny, "passthrough">>>;
