import { mapGetters as h, mapActions as P } from "vuex";
import { debounce as L, isNil as F, isArray as f, has as q } from "lodash-es";
import D from "jquery";
import A from "../utils/fileTypes.mjs";
import k from "../widgets/Pagination.vue.mjs";
import T from "../facets/SelectedFacetsOverview.vue.mjs";
import I from "../widgets/AppLink.vue.mjs";
import { truncate as B, getTranslationFor as M, getImg as N } from "../utils/helpers.mjs";
import _ from "./DatasetsTopControls.vue.mjs";
import E from "./DatasetsFilters.vue.mjs";
import G from "./DatasetList.vue.mjs";
import "@unhead/vue";
import "merge-anything";
import "../configurations/config-schema/apiSchema.mjs";
import "../configurations/config-schema/authenticationSchema.mjs";
import "../configurations/config-schema/contentSchema.mjs";
import "../configurations/config-schema/routingSchema.mjs";
import "../configurations/config-schema/metadataSchema.mjs";
import "../configurations/config-schema/languagesSchema.mjs";
import "../configurations/config-schema/themesSchema.mjs";
import "../configurations/config-schema/trackerSchema.mjs";
import "../configurations/config-schema/configSchema.mjs";
import { resolveComponent as n, openBlock as o, createElementBlock as l, createVNode as p, createTextVNode as i, createElementVNode as r, renderSlot as m, toDisplayString as d, createBlock as y, createCommentVNode as c, normalizeClass as R, withCtx as j } from "vue";
import "vue-router";
import { useDatasetsHead as U } from "../composables/head/useDatasetsHead.mjs";
import "vue-i18n";
import Q from "./datasetsFacets/DatasetsFacets.vue.mjs";
import "./Datasets.vue2.mjs";
import V from "../_virtual/_plugin-vue_export-helper.mjs";
const H = {
  name: "Datasets",
  components: {
    DatasetsFilters: E,
    DatasetsTopControls: _,
    appLink: I,
    selectedFacetsOverview: T,
    datasetsFacets: Q,
    pagination: k,
    DatasetList: G
    // Facets
  },
  props: {
    infiniteScrolling: {
      type: Boolean,
      default: !1
    },
    /**
     * @description Sets the catalog filter to a fixed catalog id. Disables the catalog facet and hides the facet in the selected facets overview.
     * @dev Use this prop if you want to use this component in a catalog page context where the catalog is already known (e.g., provider's page).
     */
    fixedCatalogFilter: {
      type: String,
      default: ""
    }
  },
  data() {
    return {
      baseUrl: this.$env.api.baseUrl,
      debouncedOnBottomScroll: L(this.onBottomScroll, 500),
      facetFields: [],
      lang: this.locale,
      filterCollapsed: !0,
      catalogAllowed: !1,
      useDatasetFacets: this.$env.content.datasets.facets.useDatasetFacets
    };
  },
  computed: {
    ...h("catalogDetails", [
      "getCatalog"
    ]),
    ...h("datasets", [
      "getDatasets",
      "getDatasetsCount",
      "getLimit",
      "getLoading",
      "getOffset",
      "getPage",
      "getPageCount",
      "getMinScoring"
    ]),
    ...h("datasets", {
      // Rename getters to something different because we'll perform some modifications on them.
      // These modifications involve removing catalog related information from facets for fixed catalog filter mode
      getAllAvailableFacetsOriginal: "getAllAvailableFacets",
      getFacetsOriginal: "getFacets"
    }),
    showCatalogDetails() {
      return !F(this.$route.params.ctlg_id) || this.fixedCatalogFilter;
    },
    /**
     * @description Returns the current page.
     * @returns {Number}
     *
     * @deprecated use getPage from datasets store instead
     */
    page() {
      return this.$route.query.page;
    },
    /**
     * @description Returns the active facets according to the route parameters.
     * @returns {Object}
     */
    facets() {
      const t = this.$env.content.datasets.facets.defaultFacetOrder, e = this.showCatalogDetails, g = t.reduce((s, a) => (s[a] = e && a === "catalog" && !this.fixedCatalogFilter ? [this.$route.params.ctlg_id || void 0] : this.getUrlFacetsOrDefault(a), s), {});
      return this.fixedCatalogFilter ? {
        ...g,
        superCatalog: [this.fixedCatalogFilter]
      } : g;
    },
    getAllAvailableFacets() {
      return this.showCatalogDetails ? this.getAllAvailableFacetsOriginal.filter((t) => t.id !== "catalog") : this.getAllAvailableFacetsOriginal;
    },
    getFacets() {
      return this.showCatalogDetails ? {
        ...this.getFacetsOriginal,
        catalog: []
      } : this.getFacetsOriginal;
    },
    currentSearchQuery() {
      return this.$route.query.query;
    },
    showScoreDisclaimer() {
      return this.getMinScoring > 0;
    },
    dataScope() {
      return this.$route.query.dataScope ? f(this.$route.query.dataScope) && this.$route.query.dataScope.length > 0 ? this.$route.query.dataScope[0] : f(this.$route.query.dataScope) && this.$route.query.dataScope.length === 0 ? null : this.$route.query.dataScope : null;
    }
  },
  methods: {
    isNil: F,
    ...P("datasets", [
      "loadDatasets",
      "loadAdditionalDatasets",
      "setPage",
      "addFacet",
      "removeFacet",
      "setFacets",
      "setFacetOperator",
      "setFacetGroupOperator",
      "setDataServices",
      "setPageCount",
      "setLimit",
      "setLoading",
      "setDataScope"
    ]),
    // The imported Lodash has function. Must be defined in Methods so we can use it in template
    has: q,
    isArray: f,
    truncate: B,
    getTranslationFor: M,
    getImg: N,
    /**
     * @description Handler-function for the scroll event.
     */
    onScroll() {
      const t = this.$el.querySelectorAll(".dataset"), e = t[t.length - 1];
      e && e.getBoundingClientRect().bottom - window.innerHeight <= 0 && this.debouncedOnBottomScroll();
    },
    /**
     * @description Handler-function when bottom of the page is reached.
     */
    onBottomScroll() {
      this.$nextTick(() => {
        this.$Progress.start(), this.loadAdditionalDatasets().then(() => {
          this.$Progress.finish();
        }).catch(() => {
          this.$Progress.fail();
        });
      });
    },
    initLimit() {
      const t = parseInt(this.$route.query.limit, 10);
      t > 0 && this.setLimit(t);
    },
    setPageLimit(t) {
      this.setLimit(t), this.initDatasets();
    },
    initDataScope() {
      this.setDataScope(this.dataScope);
    },
    /**
     * @description Determines the current page.
     */
    initPage() {
      const t = parseInt(this.$route.query.page, 10);
      t > 0 ? this.setPage(t) : this.setPage(1);
    },
    /**
     * @descritption Initialize the active facets by checking the route parameters
     */
    initFacets() {
      const t = this.$env.content.datasets.facets.defaultFacetOrder, e = this.facets;
      this.facetFields.push(...t);
      const u = t.filter((s) => !(e[s] && e[s].length > 0) && !this.$route.query[s]).reduce((s, a) => (s[a] = [], s), {});
      Object.keys(u) > 0 && this.$router.push({ query: { ...this.$route.query, ...u } }), this.setFacets(e);
    },
    getUrlFacetsOrDefault(t) {
      const e = this.$route.query[t];
      return Array.isArray(e) ? e : e ? [e] : [];
    },
    initFacetOperator() {
      if (this.showCatalogDetails)
        this.setFacetOperator("AND");
      else {
        const t = this.$route.query.facetOperator;
        (t === "AND" || t === "OR") && this.setFacetOperator(t);
      }
    },
    initFacetGroupOperator() {
      if (this.showCatalogDetails)
        this.setFacetGroupOperator("AND");
      else {
        const t = this.$route.query.facetOperator;
        (t === "AND" || t === "OR") && this.setFacetGroupOperator(t);
      }
    },
    /**
     * @descritption Initialize the active data services facet by checking the route parameters
     */
    initDataServices() {
      const t = this.$route.query.dataServices;
      t === "true" || t === "false" ? this.setDataServices(t) : this.setDataServices("false");
    },
    initDatasets() {
      this.$nextTick(() => {
        this.$nextTick(() => {
          this.$Progress.start(), this.loadDatasets({ locale: this.$route.query.locale }).then(() => {
            this.setPageCount(Math.ceil(this.getDatasetsCount / this.getLimit)), this.$Progress.finish(), D('[data-toggle="tooltip"]').tooltip({
              container: "body"
            });
          }).catch((t) => {
            console.error(t), this.$Progress.fail();
          }).finally(() => this.$root.$emit("contentLoaded"));
        });
      });
    },
    initInfiniteScrolling() {
      this.infiniteScrolling && window.addEventListener("scroll", this.onScroll);
    },
    getFileTypeColor(t) {
      return A.getFileTypeColor(t);
    }
  },
  watch: {
    // eslint-disable-next-line object-shorthand
    page(t) {
      const e = parseInt(t, 10);
      e > 0 ? this.setPage(e) : this.setPage(1);
    },
    dataScope: {
      handler() {
        this.initDataScope();
      },
      deep: !0
    }
  },
  created() {
    this.initDataScope(), this.initLimit(), this.initPage(), this.initFacetOperator(), this.initFacetGroupOperator(), this.initDataServices(), this.initFacets(), this.initDatasets(), this.initInfiniteScrolling();
  },
  mounted() {
    this.$route.query.refresh === "true" && this.$nextTick(() => {
      this.$nextTick(() => {
        this.loadDatasets({ locale: this.$route.query.locale }).then(() => {
          this.$router.push({ query: { locale: this.$route.query.locale } });
        }).catch(() => {
          this.$Progress.fail();
        });
      });
    });
  },
  beforeUnmount() {
    D(".tooltip").remove(), this.infiniteScrolling && window.removeEventListener("scroll", this.onScroll);
  },
  setup() {
    U();
  }
}, W = { class: "datasets-container d-flex flex-column p-0 bg-transparent" }, z = { class: "container-fluid datasets content" }, J = {
  key: 0,
  class: "row col-12 page-title catalog-title text-primary"
}, K = {
  key: 1,
  class: "row col-12 page-title text-primary"
}, X = { class: "row" }, Y = { class: "col d-flex d-md-none justify-content-end flex-wrap" }, Z = {
  key: 0,
  class: "material-icons small-icon align-bottom"
}, x = {
  key: 1,
  class: "material-icons small-icon align-bottom"
}, tt = { class: "col-md-9 col-12" }, et = {
  key: 0,
  class: "loading-spinner ml-3"
}, at = {
  key: 0,
  class: "alert alert-warning mt-3 d-flex flex-row"
}, st = {
  key: 3,
  class: "loading-spinner mx-auto mt-3 mb-3"
}, it = { class: "row" }, ot = { class: "column col-12 col-md-9 offset-md-3" };
function rt(t, e, g, u, s, a) {
  const S = n("datasets-top-controls"), v = n("datasets-facets"), $ = n("datasets-filters"), C = n("app-link"), b = n("selectedFacetsOverview"), O = n("dataset-list"), w = n("pagination");
  return o(), l("div", W, [
    p(S, {
      facets: a.facets,
      getPage: t.getPage,
      getLimit: t.getLimit,
      class: "datasets-top-controls"
    }, null, 8, ["facets", "getPage", "getLimit"]),
    e[11] || (e[11] = i()),
    r("div", z, [
      m(t.$slots, "title", {}, () => [
        a.showCatalogDetails ? (o(), l("h1", J, d(a.getTranslationFor(t.getCatalog.title, t.$route.query.locale, t.getCatalog.languages)), 1)) : (o(), l("h1", K, d(t.$t("message.header.navigation.data.datasets")), 1))
      ], !0),
      e[9] || (e[9] = i()),
      m(t.$slots, "content", {
        datasetsCount: t.getDatasetsCount,
        datasets: t.getDatasets,
        locale: t.$route.query.locale,
        loading: t.getLoading,
        useDatasetFacets: s.useDatasetFacets,
        facets: a.getFacets,
        availableFacets: a.getAllAvailableFacets
      }, () => [
        r("div", X, [
          r("div", Y, [
            r("button", {
              class: "btn btn-primary mb-3 text-right text-white",
              "data-toggle": "collapse",
              "data-target": "#datasetFacets",
              "data-cy": "btn-filter-toggle",
              onClick: e[0] || (e[0] = (lt) => s.filterCollapsed = !s.filterCollapsed)
            }, [
              s.filterCollapsed ? (o(), l("i", Z, "arrow_drop_up")) : (o(), l("i", x, "arrow_drop_down"))
            ])
          ]),
          e[7] || (e[7] = i()),
          s.useDatasetFacets ? (o(), y(v, {
            key: 0,
            class: "col-md-3 col-12 mb-3 mb-md-0 px-0 collapse",
            id: "datasetFacets",
            dataScope: a.dataScope,
            "available-facets": a.getAllAvailableFacets
          }, null, 8, ["dataScope", "available-facets"])) : c("", !0),
          e[8] || (e[8] = i()),
          r("section", tt, [
            m(t.$slots, "datasets-filters", {}, () => [
              p($)
            ], !0),
            e[2] || (e[2] = i()),
            m(t.$slots, "datasets-found", {
              data: {
                loading: t.getLoading,
                datasetsCount: t.getDatasetsCount,
                datasetsCountFormatted: t.getDatasetsCount.toLocaleString("fi"),
                loadingMessage: t.$t("message.datasets.loadingMessage"),
                countMessage: t.$t("message.datasets.countMessage")
              }
            }, () => [
              r("div", {
                class: R(["datasets-found alert alert-primary mt-3 d-flex flex-row", { "alert-danger": t.getDatasetsCount <= 0 && !t.getLoading }]),
                role: "status"
              }, [
                r("div", null, d(t.getLoading ? t.$t("message.datasets.loadingMessage") : `${t.getDatasetsCount.toLocaleString("fi")}
                  ${t.$t("message.datasets.countMessage")}`), 1),
                e[1] || (e[1] = i()),
                t.getLoading ? (o(), l("div", et)) : c("", !0)
              ], 2)
            ], !0),
            e[3] || (e[3] = i()),
            a.showScoreDisclaimer ? (o(), l("div", at, [
              r("span", null, [
                i(d(t.$t("message.datasets.scoreDisclaimer")) + " ", 1),
                p(C, {
                  path: "/mqa",
                  query: { locale: t.$route.query.locale },
                  target: "_blank"
                }, {
                  default: j(() => [
                    r("span", null, d(t.$t("message.metadata.methodologyPage")), 1)
                  ]),
                  _: 1
                }, 8, ["query"])
              ])
            ])) : c("", !0),
            e[4] || (e[4] = i()),
            a.getFacets ? (o(), y(b, {
              key: 1,
              "selected-facets": a.getFacets,
              "available-facets": a.getAllAvailableFacets
            }, null, 8, ["selected-facets", "available-facets"])) : c("", !0),
            e[5] || (e[5] = i()),
            t.getLoading ? c("", !0) : (o(), y(O, {
              key: 2,
              datasets: t.getDatasets,
              locale: t.$route.query.locale || "en"
            }, null, 8, ["datasets", "locale"])),
            e[6] || (e[6] = i()),
            t.getLoading ? (o(), l("div", st)) : c("", !0)
          ])
        ])
      ], !0),
      e[10] || (e[10] = i()),
      r("div", it, [
        r("div", ot, [
          p(w, {
            class: "mt-3",
            "items-count": t.getDatasetsCount,
            "items-per-page": t.getLimit,
            "get-page": t.getPage,
            "get-page-count": t.getPageCount,
            onSetPageLimit: a.setPageLimit
          }, null, 8, ["items-count", "items-per-page", "get-page", "get-page-count", "onSetPageLimit"])
        ])
      ])
    ])
  ]);
}
const _t = /* @__PURE__ */ V(H, [["render", rt], ["__scopeId", "data-v-6558a4e6"]]);
export {
  _t as default
};
//# sourceMappingURL=Datasets.vue.mjs.map
