import { mapGetters as y, mapActions as C } from "vuex";
import { isNil as f, isArray as h, isObject as D, isString as E, has as q, isNumber as R } from "lodash-es";
import $ from "./DatasetsFacetsItem.vue.mjs";
import { getTranslationFor as M, getFacetTranslation as k } from "../../utils/helpers.mjs";
import P from "./DatasetsMapFacet.vue.mjs";
import I from "../../facets/CatalogDetailsFacet.vue.mjs";
import G from "./SettingsFacet.vue.mjs";
import "@unhead/vue";
import "merge-anything";
import "../../configurations/config-schema/apiSchema.mjs";
import "../../configurations/config-schema/authenticationSchema.mjs";
import "../../configurations/config-schema/contentSchema.mjs";
import "../../configurations/config-schema/routingSchema.mjs";
import "../../configurations/config-schema/metadataSchema.mjs";
import "../../configurations/config-schema/languagesSchema.mjs";
import "../../configurations/config-schema/themesSchema.mjs";
import "../../configurations/config-schema/trackerSchema.mjs";
import "../../configurations/config-schema/configSchema.mjs";
import { resolveComponent as u, openBlock as c, createElementBlock as d, createElementVNode as m, renderSlot as v, createVNode as T, createTextVNode as n, createBlock as p, createCommentVNode as g, Fragment as L, renderList as B, normalizeClass as j } from "vue";
import "vue-router";
import "vue-i18n";
import { useDatasetsFacetsHead as U } from "../../composables/head/useDatasetsFacetsHead.mjs";
import "./DatasetsFacets.vue2.mjs";
import N from "../../_virtual/_plugin-vue_export-helper.mjs";
const Q = {
  name: "datasetsFacets",
  components: {
    SettingsFacet: G,
    CatalogDetailsFacet: I,
    DatasetsMapFacet: P,
    DatasetsFacetsItem: $
  },
  props: {
    dataScope: {
      type: String,
      default: null
    },
    availableFacets: {
      type: Array,
      default: null
    },
    /**
    * @description Sets the catalog filter to a fixed catalog id. Disables the catalog facet and hides the facet in the selected facets overview.
    * @dev Use this prop if you want to use this component in a catalog page context where the catalog is already known (e.g., provider's page).
    */
    fixedCatalogFilter: {
      type: String,
      default: ""
    }
  },
  data() {
    return {
      cutoff: this.$env.content.datasets.facets.cutoff,
      showClearButton: this.$env.content.datasets.facets.showClearButton,
      showFacetsTitle: this.$env.content.datasets.facets.showFacetsTitle,
      defaultFacetOrder: this.$env.content.datasets.facets.defaultFacetOrder,
      useScoringFacets: this.$env.content.datasets.facets.scoringFacets.useScoringFacets,
      useDataScopeFacets: f(this.$route.params.ctlg_id),
      showCatalogDetails: !1,
      catalog: {},
      MIN_FACET_LIMIT: this.$env.content.datasets.facets.MIN_FACET_LIMIT,
      MAX_FACET_LIMIT: this.$env.content.datasets.facets.MAX_FACET_LIMIT,
      FACET_OPERATORS: this.$env.content.datasets.facets.FACET_OPERATORS,
      FACET_GROUP_OPERATORS: this.$env.content.datasets.facets.FACET_GROUP_OPERATORS,
      dataServices: {
        yes: this.i18n.global.t("message.metadata.yes"),
        no: this.i18n.global.t("message.metadata.no"),
        property: this.i18n.global.t("message.datasetFacets.facets.dataServices.dataServicesOnly"),
        title: this.i18n.global.t("message.metadata.dataServices"),
        toolTipTitle: this.i18n.global.t("message.helpIcon.dataServices")
      },
      erpd: {
        yes: this.i18n.global.t("message.metadata.yes"),
        no: this.i18n.global.t("message.metadata.no"),
        property: this.i18n.global.t("message.datasetFacets.facets.erpdOnly"),
        title: this.i18n.global.t("message.metadata.erpd")
        // toolTipTitle: "TOOLTIP",//this.i18n.global.t('message.helpIcon.dataServices'),
      }
    };
  },
  computed: {
    ...y("catalogDetails", [
      "getCatalog"
    ]),
    ...y("datasets", [
      "getAllAvailableFacets",
      "getDatasetsCount",
      "getFacets",
      "getFacetOperator",
      "getFacetGroupOperator",
      "getDataServices",
      "getLimit",
      "getMinScoring",
      "getPage",
      "getDatasetGeoBounds",
      "getScoringFacets"
    ]),
    resolvedAvailableFacets() {
      return this.availableFacets || this.getAllAvailableFacets;
    },
    datasetBoundsWatcher() {
      return this.getDatasetGeoBounds;
    },
    facetGroupOperatorWatcher() {
      return this.getFacetGroupOperator;
    },
    // dataServicesWatcher() {
    //   return this.getDataServices;
    // },
    // catalogWatcher() {
    //   return this.getCatalog;
    // },
    // showCatalogDetailsWatcher() {
    //   return !isNil(this.$route.params.ctlg_id);
    // },
    useCatalogFacets() {
      return !this.showCatalogDetails;
    },
    currentSearchQuery() {
      return this.$route.query.query;
    },
    showMoreFacetsShown() {
      return this.$env.content.datasets.facets.cutoff > 0 && this.$env.content.datasets.facets.cutoff < this.getAllVisibleFacets.length;
    },
    getAllVisibleFacets() {
      return this.resolvedAvailableFacets.filter((t) => t.items.length > 0);
    },
    getSortedFacets() {
      const t = this.resolvedAvailableFacets, e = [], a = [];
      let o = Object.keys(this.getFacets).filter((r) => this.getFacets[r].length > 0);
      this.defaultFacetOrder.forEach((r) => {
        t.forEach((l) => {
          r === l.id && l.items.length > 0 && (o.includes(l.id) ? e.push(l) : a.push(l));
        });
      });
      const s = e.concat(a);
      return this.cutoff > 0 ? (this.cutoff < e.length && (this.cutoff = e.length), s.slice(0, this.cutoff)) : s;
    },
    // Returns the current catalog's available language ids
    // example: ['en', 'de', 'sv']
    catalogLanguageIds() {
      const t = this.getCatalog && this.getCatalog.languages;
      return h(t) ? t.map((e) => e && e.id).filter((e) => e) : [];
    },
    isErdp() {
      if (this.$route.path === "/catalogues/erpd")
        return "true";
      {
        const t = this.getFacets.superCatalog;
        return t && t[0] === "erpd" ? "true" : "false";
      }
    }
  },
  methods: {
    isObject: D,
    isArray: h,
    isString: E,
    has: q,
    isNil: f,
    isNumber: R,
    getTranslationFor: M,
    getFacetTranslation: k,
    ...C("catalogDetails", [
      "loadCatalog"
    ]),
    ...C("datasets", [
      "addFacet",
      "removeFacet",
      "setFacetGroupOperator",
      "setDataServices",
      "setSuperCatalogue_DEPRECATED",
      // !!!!! Project specific (Bayern). Should be removed as soon as possible !!!!
      "setPage",
      "setPageCount",
      "setMinScoring"
    ]),
    toggleCutoff() {
      this.cutoff = this.cutoff >= 0 ? -1 : this.$env.content.datasets.facets.cutoff;
    },
    facetTitle(t) {
      return t === "scoring" ? this.i18n.global.t("message.header.navigation.data.metadataquality") : this.i18n.global.t(`message.datasetFacets.facets.${t.toLowerCase()}`);
    },
    tooltip(t) {
      return t === "dataScope" ? this.i18n.global.t("message.helpIcon.dataScope") : this.i18n.global.t(`message.helpIcon.${t.toLowerCase()}`);
    },
    getFacetTranslationWrapper(t, e, a, o) {
      return t === "scoring" ? this.$t(`message.datasetFacets.facets.scoring.${e}`) : this.getFacetTranslation(t, e, a, o);
    },
    sortByCount(t, e) {
      return e === "scoring" || e === "dataScope" ? t : t.slice().sort((a, o) => o.count - a.count !== 0 ? o.count - a.count : a.name < o.name ? -1 : 1);
    },
    setRouteQuery(t, e) {
      return e === "replace" ? this.$router.replace(
        { query: Object.assign({}, this.$route.query, t) }
      ).catch(
        (a) => {
          console.error(a);
        }
      ) : this.$router.push(
        { query: Object.assign({}, this.$route.query, t) }
      ).catch(
        (a) => {
          console.error(a);
        }
      );
    },
    facetIsSelected(t, e) {
      const a = e.id;
      if (t === "scoring") {
        const s = parseInt(this.getMinScoring, 10), r = this.$route.query[t];
        return !r || !s ? e.minScoring === 0 : r && s === e.minScoring;
      }
      if (!Object.prototype.hasOwnProperty.call(this.$route.query, t))
        return !1;
      if (t === "dataScope")
        return this.$route.query.dataScope === a;
      let o = this.$route.query[t];
      return Array.isArray(o) || (o = [o]), t === "categories" && (a.toUpperCase(), o = o.map((s) => s.toUpperCase())), o.indexOf(a) > -1;
    },
    facetClicked(t, e) {
      const a = e.id;
      t === "dataScope" ? this.dataScopeFacetClicked(a) : (t === "scoring" && this.scoringFacetClicked(e), t === "country" && (a === "eu" ? this.$route.query.dataScope = "eu" : a === "io" ? this.$route.query.dataScope = "io" : this.$route.query.dataScope = "countryData"), this.toggleFacet(t, a));
    },
    toggleFacet(t, e) {
      var o, s;
      Object.prototype.hasOwnProperty.call(this.$route.query, [t]) || this.setRouteQuery({ [t]: [], page: 1 });
      let a = (s = (o = this.$route.query) == null ? void 0 : o[t]) == null ? void 0 : s.slice();
      if (a || (a = []), Array.isArray(a) || (a = [a]), t === "categories" && (e.toUpperCase(), a = a.map((r) => r.toUpperCase())), t === "scoring")
        a = e === "badScoring" ? [] : [e];
      else {
        const r = a.indexOf(e);
        r > -1 ? a.splice(r, 1) : a.push(e);
      }
      return this.setRouteQuery({ [t]: a, page: 1 });
    },
    clearFacets() {
      Object.keys(this.$route.query).some((t) => t !== "locale" && t !== "page" && this.$route.query[t].length) && (this.setMinScoring(0), this.$router.push({ query: { locale: this.$i18n.locale, page: "1" } }).catch((t) => {
        console.error(t);
      })), sessionStorage.clear();
    },
    dataScopeFacetClicked(t) {
      if (this.$route.query.dataScope === t)
        this.setRouteQuery({ dataScope: [], country: [], page: 1 });
      else {
        const e = [];
        e.push(t), this.setRouteQuery({ dataScope: t, country: e, page: 1 });
      }
    },
    scoringFacetClicked(t) {
      let e = t.minScoring;
      e === this.getMinScoring && (e = 0), this.setMinScoring(e), this.resetPage(), window.scrollTo(0, 0);
    },
    toggleFacetGroupOperator() {
      let t = this.getFacetGroupOperator;
      t = t === this.FACET_GROUP_OPERATORS.and ? this.FACET_GROUP_OPERATORS.or : this.FACET_GROUP_OPERATORS.and, this.setFacetGroupOperator(t);
    },
    changeDataServices(t) {
      this.setDataServices(t);
      const e = Object.assign({}, this.$route.query, { dataServices: t, page: 1 });
      t === "false" && delete e.dataServices, this.$router.replace({ query: e });
    },
    changeErpd(t) {
      if (this.$route.path === "/catalogues/erpd") {
        const e = Object.assign({}, this.$route.query, { page: 1 });
        this.$router.replace({
          path: "/datasets",
          query: e
        });
      } else {
        const e = t === "true" ? "erpd" : "false", a = Object.assign({}, this.$route.query, { superCatalog: e, page: 1 });
        e === "false" && delete a.superCatalog, this.$router.replace({ query: a });
      }
    },
    resetPage() {
      this.setRouteQuery({ page: 1 }, "replace");
    },
    getFacetCount(t, e) {
      return t.id === "scoring" ? "" : e.count;
    },
    initShowCatalogDetails() {
      !f(this.$route.params.ctlg_id) === !0 ? (this.showCatalogDetails = !0, this.loadCatalog(this.$route.params.ctlg_id)) : this.showCatalogDetails = !1;
    },
    initMinScoring() {
      let t = this.$route.query.scoring;
      if (t = h(t) && t.length > 0 ? t[0] : h(t) && t.length === 0 ? "" : t, t) {
        let e = this.$env.content.datasets.facets.scoringFacets.defaultScoringFacets;
        Object.keys(e).forEach((a) => {
          a === t && this.setMinScoring(e[a].minScoring);
        });
      } else
        this.setMinScoring(0);
    },
    isMultiSelect(t) {
      return t !== "scoring";
    }
  },
  watch: {
    facetGroupOperatorWatcher: {
      handler(t) {
        this.setRouteQuery({ facetGroupOperator: t }, "replace");
      }
    },
    // getDataServices(dataServices) {
    //   this.$router.replace(
    //     { query: Object.assign({}, this.$route.query, { dataServices }) }
    //   ).catch(
    //     error => { console.error(error); }
    //   );
    // },
    "$route.params.ctlg_id"(t) {
      this.showCatalogDetails = t;
    },
    getDatasetGeoBounds(t) {
      this.bounds = t;
    },
    getCatalog(t) {
      this.catalog = t;
    }
  },
  created() {
    this.initShowCatalogDetails(), this.initMinScoring();
    for (var t in sessionStorage)
      sessionStorage.length > 0 && t == "Filter" && this.toggleCutoff();
  },
  setup() {
    U();
  }
}, W = { class: "container dataset-facets" }, V = { class: "row mx-3 mr-md-0" }, x = { class: "col" }, X = {
  key: 1,
  class: "row h5 font-weight-bold mt-4 mb-3"
};
function z(t, e, a, o, s, r) {
  const l = u("datasets-map-facet"), O = u("catalog-details-facet"), b = u("settings-facet"), F = u("radio-facet"), _ = u("select-facet"), w = u("pv-show-more"), A = u("pv-button");
  return c(), d("div", W, [
    m("div", V, [
      v(t.$slots, "content", { facets: r.getSortedFacets }, () => [
        m("div", x, [
          T(l, { showCatalogDetails: s.showCatalogDetails }, null, 8, ["showCatalogDetails"]),
          e[2] || (e[2] = n()),
          s.showCatalogDetails ? (c(), p(O, {
            key: 0,
            class: "catalog-details",
            catalog: s.catalog,
            catalogLanguageIds: r.catalogLanguageIds
          }, null, 8, ["catalog", "catalogLanguageIds"])) : g("", !0),
          e[3] || (e[3] = n()),
          s.showFacetsTitle ? (c(), d("span", X, "Filter by")) : g("", !0),
          e[4] || (e[4] = n()),
          T(b, { class: "row facet-field mb-3" }),
          e[5] || (e[5] = n()),
          (c(!0), d(L, null, B(r.getSortedFacets, (i, S) => (c(), d("div", {
            class: j(["row facet-field mb-3", { "mt-3": S > 0 }]),
            key: `facet@${i.id}`
          }, [
            v(t.$slots, "facet", {
              field: i,
              index: S
            }, () => [
              i.id === "dataServices" ? (c(), p(F, {
                key: 0,
                title: s.dataServices.title,
                property: s.dataServices.property,
                toolTipTitle: s.dataServices.toolTipTitle,
                optionIds: ["true", "false"],
                optionLabels: [s.dataServices.yes, s.dataServices.no],
                initialOption: t.getDataServices,
                change: r.changeDataServices
              }, null, 8, ["title", "property", "toolTipTitle", "optionLabels", "initialOption", "change"])) : g("", !0),
              e[0] || (e[0] = n()),
              i.id === "superCatalog" ? (c(), p(F, {
                key: 1,
                title: s.erpd.title,
                property: s.erpd.property,
                toolTipTitle: s.erpd.toolTipTitle,
                optionIds: ["true", "false"],
                optionLabels: [s.erpd.yes, s.erpd.no],
                initialOption: r.isErdp,
                change: r.changeErpd
              }, null, 8, ["title", "property", "toolTipTitle", "optionLabels", "initialOption", "change"])) : g("", !0),
              e[1] || (e[1] = n()),
              i.id !== "superCatalog" && i.id !== "dataServices" ? (c(), p(_, {
                key: 2,
                fieldId: i.id,
                header: r.facetTitle(i.id),
                items: r.sortByCount(i.items, i.id),
                toolTipTitle: r.tooltip(i.id),
                getFacetTranslationWrapper: r.getFacetTranslationWrapper,
                facetIsSelected: r.facetIsSelected,
                facetClicked: r.facetClicked,
                multiSelect: r.isMultiSelect(i.id),
                class: "col pr-0"
              }, null, 8, ["fieldId", "header", "items", "toolTipTitle", "getFacetTranslationWrapper", "facetIsSelected", "facetClicked", "multiSelect"])) : g("", !0)
            ], !0)
          ], 2))), 128)),
          e[6] || (e[6] = n()),
          m("div", null, [
            r.showMoreFacetsShown ? (c(), p(w, {
              key: 0,
              label: s.cutoff >= 0 ? t.$t("message.datasetFacets.moreFilters") : t.$t("message.datasetFacets.lessFilters"),
              upArrow: s.cutoff === -1,
              action: r.toggleCutoff,
              class: "p-0 row facets-show-more"
            }, null, 8, ["label", "upArrow", "action"])) : g("", !0)
          ]),
          e[7] || (e[7] = n()),
          s.showClearButton ? (c(), p(A, {
            key: 2,
            label: "Clear filters",
            class: "row mt-5 facets-clear",
            action: r.clearFacets
          }, null, 8, ["action"])) : g("", !0)
        ])
      ], !0)
    ])
  ]);
}
const yt = /* @__PURE__ */ N(Q, [["render", z], ["__scopeId", "data-v-c26e9ef7"]]);
export {
  yt as default
};
//# sourceMappingURL=DatasetsFacets.vue.mjs.map
