import A from "axios";
import { get as o, cloneDeep as u } from "lodash-es";
import i from "../../utils/draftApi.mjs";
import f from "../../utils/identifiersApi.mjs";
import { decode as R } from "../../utils/jwt.mjs";
let _, T;
const d = {
  authenticated: !1,
  rtptoken: "",
  keycloak: null,
  userData: {
    authToken: "",
    rtpToken: "",
    userName: "",
    permissions: [],
    drafts: [],
    roles: []
  },
  isEditMode: !1,
  isDraft: !1
}, U = {
  securityAuth: (e) => e.authenticated,
  getRTPToken: (e) => e.rtptoken,
  getKeycloak: (e) => e.keycloak,
  getUserData: (e) => e.userData,
  getUserName: (e) => e.userData.userName,
  /**
   * @description Get all catalogs associated to the user where they have access to.
   * @returns {Array} Array of catalogs
   */
  getUserCatalogs: (e) => e.userData.permissions.filter(
    // User must have CRUD authorization
    (t) => ["dataset:update", "dataset:delete", "dataset:create"].every((a) => t.scopes.includes(a))
  ),
  /**
   * @description Get all catalog IDs associated to the user where they have access to.
   */
  getUserCatalogIds: (e, t) => t.getUserCatalogs.map((a) => a.rsname),
  getUserDrafts: (e) => e.userData.drafts,
  getUserDraftIds: (e) => e.userData.drafts.map((t) => t.id),
  getIsEditMode: (e) => e.isEditMode,
  getIsDraft: (e) => e.isDraft
}, S = {
  authLogin({ commit: e }, t) {
    e("SECURITY_AUTH", t);
  },
  authLogout({ commit: e }) {
    e("SECURITY_AUTH", !1), e("RTP_TOKEN", "");
  },
  rtpToken({ commit: e }, t) {
    e("RTP_TOKEN", t);
  },
  setKeycloak({ commit: e }, t) {
    e("SET_KEYCLOAK", t);
  },
  /**
   * Updates user data according to an authentication token and by supplying neccessary
   * information to retrieve tFhe user's permissions as well as their drafts.
   * @param {*} commit
   * @param {Object} params
   * @returns {Promise<Object>}
   */
  async updateUserData({ commit: e, dispatch: t }, { authToken: a, rtpToken: s, hubUrl: r }) {
    if (!a || !s)
      return console.error("Missing authToken or rtpToken"), e("UPDATE_USER_DATA_ERROR"), {};
    e("UPDATE_USER_DATA_PENDING");
    try {
      if (!s)
        throw new Error("Failed to retrieve RTP token");
      const E = R(s), D = o(E, "authorization.permissions", []), n = o(E, "realm_access.roles", []);
      e("SET_USER_DATA", {
        authToken: a,
        rtpToken: s,
        userName: E.preferred_username,
        permissions: D,
        drafts: [],
        roles: n
      }), _ = i({ baseURL: r, authToken: s }), T = f({ baseURL: r, authToken: s }), t("updateUserDrafts"), e("UPDATE_USER_DATA_SUCCESS");
    } catch (E) {
      console.error(E), e("UPDATE_USER_DATA_ERROR");
    }
    return {};
  },
  async updateUserDrafts({ commit: e, state: t }) {
    if (!t.userData.rtpToken)
      throw new Error("Requires RTP token");
    const s = await _.getAllDatasetDrafts(), r = s.status === 200 && s.data;
    e("SET_USER_DATA", { drafts: r });
  },
  async createDataset({ commit: e }, t) {
    const a = {
      method: "PUT",
      url: t.url,
      headers: {
        "Content-Type": "text/turtle",
        Authorization: `Bearer ${t.token}`
      },
      data: t.data
    }, s = await A.request(a);
    (s.status === 201 || s.status === 204) && (e("CHANGE_IS_EDIT_MODE", !1), e("CHANGE_IS_DRAFT", !1));
  },
  /**
   * Creates a draft dataset
   * @param {*} commit
   * @param {object} dataset - The dataset object
   * @param {string} dataset.id - The ID of the dataset
   * @param {string} dataset.catalog - The ID of the dataset
   * @param {object} dataset.description - The description object of the dataset containing different locales
   * @param {object} dataset.title - The title object of the dataset containing different locales
   * @param {object} dataset.body - the JSON-LD representation of the dataset
   * @returns {Promise<Object>}
   */
  async createUserDraft({ commit: e }, {
    id: t,
    catalog: a,
    description: s = { en: "" },
    title: r = { en: "" },
    body: E = {}
  }) {
    if (!_)
      return {};
    e("UPDATE_USER_DATA_PENDING");
    let D;
    try {
      D = await _.createDatasetDraft({ id: t, catalogue: a, body: E }), e("CREATE_USER_DRAFT", {
        id: t,
        catalog: a,
        description: s,
        title: r,
        body: E
      }), e("UPDATE_USER_DATA_SUCCESS");
    } catch (n) {
      throw e("UPDATE_USER_DATA_ERROR"), n;
    }
    return D;
  },
  async deleteUserDraftById({ commit: e, state: t }, { id: a, catalog: s }) {
    if (!_)
      return {};
    if (!t.userData.drafts.find((D) => D.id === a))
      return {};
    e("UPDATE_USER_DATA_PENDING");
    let E;
    try {
      E = await _.deleteDatasetDraft({ id: a, catalogue: s }), e("DELETE_USER_DRAFT", a), e("UPDATE_USER_DATA_SUCCESS");
    } catch (D) {
      throw e("UPDATE_USER_DATA_ERROR"), D;
    }
    return E;
  },
  async publishUserDraftById({ commit: e, state: t }, { id: a, catalog: s, body: r = {} }) {
    if (!_)
      return {};
    if (!t.userData.drafts.find((n) => n.id === a))
      return {};
    e("UPDATE_USER_DATA_PENDING");
    let D;
    try {
      D = await _.publishDatasetDraft({ id: a, catalogue: s, body: r }), e("DELETE_USER_DRAFT", a), e("UPDATE_USER_DATA_SUCCESS"), e("CHANGE_IS_DRAFT", !1), e("CHANGE_IS_EDIT_MODE", !1);
    } catch (n) {
      throw e("UPDATE_USER_DATA_ERROR"), n;
    }
    return D;
  },
  async duplicateDataset({ commit: e, state: t }, { id: a, newId: s, catalog: r, url: E }) {
    console.log(a, r, E);
    const D = {
      method: "GET",
      url: E + "drafts/datasets/" + a + ".nt?catalogue=" + r
    };
    await A.request(D);
  },
  async publishUserDraft({ dispatch: e }, { id: t, catalog: a, body: s }) {
    return e("publishUserDraftById", { id: t, catalog: a, body: s });
  },
  async putDatasetToDraft({ commit: e }, {
    id: t,
    catalog: a,
    title: s,
    description: r
  }) {
    if (!_)
      return {};
    e("UPDATE_USER_DATA_PENDING");
    let E;
    try {
      E = await _.putDatasetToDraft({ id: t, catalogue: a }), e("PUT_DATASET_TO_DRAFT", {
        id: t,
        catalog: a,
        title: s,
        description: r
      }), e("UPDATE_USER_DATA_SUCCESS");
    } catch (D) {
      throw e("UPDATE_USER_DATA_ERROR"), D;
    }
    return E;
  },
  setIsEditMode({ commit: e }, t) {
    e("CHANGE_IS_EDIT_MODE", t);
  },
  setIsDraft({ commit: e }, t) {
    e("CHANGE_IS_DRAFT", t);
  },
  async createPersistentIdentifier({ commit: e }, { id: t, catalog: a, type: s = "mock" }) {
    if (!T)
      return {};
    e("UPDATE_USER_DATA_PENDING");
    let r;
    try {
      r = await T.createPersistentIdentifier({ id: t, catalogue: a, type: s }), e("UPDATE_USER_DATA_SUCCESS");
    } catch (E) {
      throw e("UPDATE_USER_DATA_ERROR"), E;
    }
    return r;
  },
  populateDraftAndEdit({ commit: e }) {
    e("PREDEFINE_DRAFT_AND_EDIT");
  },
  async createCatalogue({ commit: e }, t) {
    const a = {
      method: "PUT",
      url: t.url,
      headers: {
        "Content-Type": "text/turtle",
        Authorization: `Bearer ${t.token}`
      },
      data: t.data
    }, s = await A.request(a);
    if (s.status === 201 | s.status === 204) {
      e("CHANGE_IS_EDIT_MODE", !1), e("CHANGE_IS_DRAFT", !1);
      const r = u(d.userData), E = {
        rsid: "",
        rsname: t.id,
        scopes: ["dataset:update", "dataset:delete", "dataset:create"]
      };
      r.permissions.push(E), e("SET_USER_DATA", r);
    }
  }
}, l = {
  SECURITY_AUTH(e, t) {
    e.authenticated = t;
  },
  RTP_TOKEN(e, t) {
    e.rtptoken = t;
  },
  SET_KEYCLOAK(e, t) {
    e.keycloak = t;
  },
  SET_USER_DATA(e, t) {
    e.userData = { ...e.userData, ...t };
  },
  UPDATE_USER_DATA_PENDING(e) {
    e.userData.pending = !0;
  },
  UPDATE_USER_DATA_SUCCESS(e) {
    e.userData.pending = !1;
  },
  UPDATE_USER_DATA_ERROR(e) {
    e.userData.pending = !1;
  },
  CREATE_USER_DRAFT(e, {
    id: t,
    catalog: a,
    title: s,
    description: r
  }) {
    e.userData.drafts.push({
      id: t,
      catalog: a,
      title: s,
      description: r
    });
  },
  PUT_DATASET_TO_DRAFT(e, {
    id: t,
    catalog: a,
    title: s,
    description: r
  }) {
    e.userData.drafts.push({
      id: t,
      catalog: a,
      title: s,
      description: r
    });
  },
  DELETE_USER_DRAFT(e, t) {
    const a = e.userData.drafts.findIndex((s) => s.id === t);
    a > -1 && e.userData.drafts.splice(a, 1);
  },
  CHANGE_IS_EDIT_MODE(e, t) {
    e.isEditMode = t, localStorage.setItem("dpi_editmode", t);
  },
  CHANGE_IS_DRAFT(e, t) {
    e.isDraft = t, localStorage.setItem("dpi_draftmode", t);
  },
  PREDEFINE_DRAFT_AND_EDIT(e) {
    const t = Object.keys(localStorage);
    t.includes("dpi_editmode") && (e.isEditMode = JSON.parse(localStorage.getItem("dpi_editmode"))), t.includes("dpi_draftmode") && (e.isDraft = JSON.parse(localStorage.getItem("dpi_draftmode")));
  }
}, C = {
  namespaced: !0,
  state: d,
  actions: S,
  mutations: l,
  getters: U
};
export {
  C as default
};
//# sourceMappingURL=authStore.mjs.map
