const P = {
  /**
   * @property catalogs
   * @type Array
   * @description An array of catalogs.
   */
  catalogs: [],
  datasetCounts: {},
  loading: !1,
  searchParameters: {
    query: "",
    limit: 10,
    offset: 0,
    facets: [],
    facetOperator: "AND",
    facetGroupOperator: "AND",
    sort: "relevance+desc,modified+desc,title+asc"
  },
  availableFacets: [],
  page: 1,
  pageCount: 1,
  catalogsCount: 0
}, r = {
  getCatalogs: (e) => e.catalogs,
  getCatalogsCount: (e) => e.catalogsCount,
  getQuery: (e) => e.searchParameters.query,
  getLimit: (e) => e.searchParameters.limit,
  getLoading: (e) => e.loading,
  getOffset: (e) => e.searchParameters.offset,
  getFacets: (e) => e.searchParameters.facets,
  getFacetOperator: (e) => e.searchParameters.facetOperator,
  getFacetGroupOperator: (e) => e.searchParameters.facetGroupOperator,
  getAvailableFacets: (e) => [
    ...e.availableFacets,
    {
      id: "erpd",
      items: [
        { count: void 0, id: "true", title: "yes" },
        { count: void 0, id: "false", title: "no" }
      ],
      title: "ERPD"
    }
  ],
  getPage: (e) => e.page,
  getPageCount: (e) => e.pageCount,
  getSort: (e) => e.searchParameters.sort
}, E = {
  /**
   * @description Load all catalogs matching the given parameters.
   * @param commit
   * @param state
   * @param options {Object} - Given search parameters
   * @param options.query {String} - The given query string
   * @param options.facets {Array} - The active facets
   * @param options.limit {Number} - The maximum amount of catalogs to fetch
   * @param options.page {Number} - The current page
   * @param options.sort {String} - The sort method to use
   * @param options.append {Boolean} - Decides whether current catalogs in state will be replaced or fetched catalogs appended.
   */
  loadCatalogs({ commit: e, state: a }, {
    query: t = r.getQuery(a),
    limit: o = r.getLimit(a),
    page: c = r.getPage(a),
    sort: g = r.getSort(a),
    facetOperator: l = r.getFacetOperator(a),
    facetGroupOperator: T = r.getFacetGroupOperator(a),
    facets: S = r.getFacets(a),
    append: _ = !1
  }) {
    return e("SET_LOADING", !0), new Promise((i, n) => {
      this.$catalogService.get(t, o, c, g, l, T, S).then((s) => {
        e("SET_AVAILABLE_FACETS", s.availableFacets), e("SET_catalogS_COUNT", s.catalogsCount), e(_ ? "ADD_catalogS" : "SET_catalogS", s.catalogs), e("SET_LOADING", !1), i();
      }).catch((s) => {
        console.error(s), e("SET_LOADING", !1), n(s);
      });
    });
  },
  /**
   * @description Loads more catalogs.
   * @param commit
   * @param state
   * @param {number} amount - The amount of catalogs to add.
   */
  loadAdditionalCatalogs({ commit: e, state: a }) {
    const t = r.getPage(a);
    E.loadCatalogs({ commit: e, state: a }, { page: t, append: !0 });
  },
  /**
   * @description Autocomplete a query String by using a autocompletion service
   * @param commit
   * @param q {String} The Query to autocomplete
   */
  autocompleteQuery({ commit: e }, a) {
    if (typeof this.$catalogService.autocomplete == "function")
      return new Promise((t, o) => {
        this.$catalogService.autocomplete(a).then((c) => {
          t(c);
        }).catch((c) => {
          o(c);
        });
      });
  },
  /**
   * @description Replace the current state facets by the given facets
   * @param commit
   * @param facets {Array} - The given facets
   */
  setFacets({ commit: e }, a) {
    a && e("SET_FACETS", a);
  },
  /**
   * @description Add the given facet to the states facets.
   * @param commit
   * @param params {Object} - The wrapped action parameters.
   * @param params.field {String} - The field of the given facet
   * @param params.facet {String} - The facet to add
   */
  addFacet({ commit: e }, { field: a, facet: t }) {
    e("ADD_FACET", { field: a, facet: t });
  },
  /**
   * @description Remove the given facet from the states facets.
   * @param commit
   * @param params {Object} - The wrapped action parameters.
   * @param params.field {String} - The field of the given facet
   * @param params.facet {String} - The facet to remove
   */
  removeFacet({ commit: e }, { field: a, facet: t }) {
    e("REMOVE_FACET", { field: a, facet: t });
  },
  /**
   * @description Remove the given facet from the states facets.
   * @param commit
   * @param operator {String} - The facet operator to set. Possible Operators : ['AND', 'OR'].
   */
  setFacetOperator({ commit: e }, a) {
    e("SET_FACET_OPERATOR", a);
  },
  /**
   * @description Remove the given facet from the states facets.
   * @param commit
   * @param operator {String} - The facet operator to set. Possible Operators : ['AND', 'OR'].
   */
  setFacetGroupOperator({ commit: e }, a) {
    e("SET_FACET_GROUP_OPERATOR", a);
  },
  /**
   * @description Handles page changes by through URL query.
   * @param commit
   * @param state
   * @param page {String} The given page number as a String
   */
  setPage({ commit: e }, a) {
    e("SET_PAGE", a);
  },
  setPageCount({ commit: e }, a) {
    e("SET_PAGE_COUNT", a);
  },
  /**
   * @description Replace the current state query by the given query
   * @param commit
   * @param query {String} - The given query
   */
  setQuery({ commit: e }, a) {
    e("SET_QUERY", a);
  },
  /**
   * @description Replace the current sort method
   * @param commit
   * @param sort {String} - The given sort method to use now
   */
  setSort({ commit: e }, a) {
    e("SET_SORT", a);
  },
  setLimit({ commit: e }, a = 10) {
    e("SET_LIMIT", a);
  },
  setLoading({ commit: e }, a) {
    e("SET_LOADING", a);
  },
  setCatalogs({ commit: e }, a) {
    e("SET_catalogS", a);
  },
  setCatalogsCount({ commit: e }, a) {
    e("SET_catalogS_COUNT", a);
  }
}, u = {
  SET_catalogS(e, a) {
    e.catalogs = a;
  },
  ADD_catalogS(e, a) {
    e.catalogs = e.catalogs.concat(a);
  },
  SET_LIMIT(e, a) {
    e.searchParameters.limit = a;
  },
  SET_OFFSET(e, a) {
    e.searchParameters.offset = a;
  },
  SET_FACETS(e, a) {
    e.searchParameters.facets = a;
  },
  ADD_FACET(e, { field: a, facet: t }) {
    Object.prototype.hasOwnProperty.call(e.searchParameters.facets, a) ? e.searchParameters.facets[a].push(t) : e.searchParameters.facets[a] = [t];
  },
  REMOVE_FACET(e, { field: a, facet: t }) {
    const o = e.searchParameters.facets[a].indexOf(t);
    e.searchParameters.facets[a].splice(o, 1);
  },
  SET_AVAILABLE_FACETS(e, a) {
    e.availableFacets = a;
  },
  SET_catalogS_COUNT(e, a) {
    e.catalogsCount = a;
  },
  SET_FACET_OPERATOR(e, a) {
    e.searchParameters.facetOperator = a;
  },
  SET_FACET_GROUP_OPERATOR(e, a) {
    e.searchParameters.facetGroupOperator = a;
  },
  SET_PAGE(e, a) {
    e.page = a;
  },
  SET_PAGE_COUNT(e, a) {
    e.pageCount = a;
  },
  SET_QUERY(e, a) {
    e.searchParameters.query = a;
  },
  SET_SORT(e, a) {
    e.searchParameters.sort = a;
  },
  SET_LOADING(e, a) {
    e.loading = a;
  }
}, A = {
  namespaced: !0,
  state: P,
  actions: E,
  mutations: u,
  getters: r
};
export {
  A as default
};
//# sourceMappingURL=cataloguesStore.mjs.map
