import { SimilarDatasetsQuery } from 'lib/services/datasetService';

declare const module: {
    namespaced: boolean;
    state: {
        dataset: {
            availability: {};
            applicableLegislation: {}[];
            politicalGeocodingLevelURI: {}[];
            politicalGeocodingURI: {}[];
            contributorID: {}[];
            geocodingDescriptionDe: {};
            hvdCategory: {}[];
            legalBasis: {};
            qualityProcessURI: string;
            typeDe: string;
            references: string;
            contributor: never[];
            originator: never[];
            maintainer: never[];
            accessRights: string;
            accrualPeriodicity: string;
            admsIdentifiers: never[];
            attributes: never[];
            catalog: {};
            categories: never[];
            conformsTo: never[];
            contactPoints: never[];
            country: {};
            creator: {};
            dateIncorrect: boolean;
            deadline: string;
            description: {};
            dimensions: never[];
            distributions: never[];
            distributionFormats: never[];
            documentations: never[];
            frequency: {};
            geocodingDescription: {};
            hasQualityAnnotations: never[];
            hasVersion: never[];
            id: string;
            identifiers: never[];
            idName: string;
            isHvd: boolean;
            isReferencedBy: never[];
            isVersionOf: never[];
            keywords: never[];
            landingPages: never[];
            languages: never[];
            licences: never[];
            modificationDate: string;
            numSeries: number;
            originalLanguage: string;
            otherIdentifiers: never[];
            pages: never[];
            provenances: never[];
            publisher: {};
            qualifiedAttributions: never[];
            qualifiedRelations: never[];
            relations: never[];
            relatedResources: never[];
            releaseDate: string;
            resource: string;
            sample: never[];
            similarDatasetsRequested: string;
            similarDatasets: never[];
            sources: never[];
            spatial: never[];
            spatialResource: never[];
            spatialResolutionInMeters: number;
            statUnitMeasures: never[];
            subject: never[];
            temporal: never[];
            temporalResolution: never[];
            theme: never[];
            translationMetaData: {};
            title: {};
            type: {};
            versionInfo: string;
            versionNotes: {};
            visualisations: never[];
            wasGeneratedBy: never[];
            qualityDataRequested: string;
            qualityData: string[];
            qualityDistributionData: string[];
            isDQVDataRequested: string;
            isDQVDataRDFAvailable: boolean;
            isDQVDataTTLAvailable: boolean;
            isDQVDataN3Available: boolean;
            isDQVDataNTAvailable: boolean;
            isDQVDataJSONLDAvailable: boolean;
            catalogRecord: {};
            isUsedBy: {};
            extendetMetadata: {};
            distributionDownloadAs: {};
            distributionDownloadAsOptions: never[];
            descriptionHeight: number;
        };
        activeNavigationTab: number;
        loading: boolean;
    };
    actions: {
        /**
         * @description Loads details for the dataset with the given ID.
         * @param commit
         * @param state
         * @param id {String} The dataset ID.
         */
        loadDatasetDetails({ state, commit }: {
            state: any;
            commit: any;
        }, id: any): Promise<unknown>;
        /**
         * @description Loads details for the dataset with the given ID. But unlike loaddatasetDetails,
         * the Mutations after the request differ because this function is meant to fetch details for similar datasets of another dataset.
         * @param commit
         * @param state
         * @param id {String} The dataset ID.
         */
        loadSimilarDatasetDetails({ state, commit }: {
            state: any;
            commit: any;
        }, id: any): Promise<unknown>;
        /**
         * @description Fetches similar datasets of the provided dataset id
         * @param idOrPayload {string | LoadSimilarDatasetsPayload} - id or payload
         */
        loadSimilarDatasets({ state, commit }: {
            state: any;
            commit: any;
        }, idOrPayload: string | LoadSimilarDatasetsPayload): Promise<unknown>;
        loadQualityData({ commit }: {
            commit: any;
        }, id: any): Promise<unknown>;
        loadQualityDistributionData({ commit }: {
            commit: any;
        }, id: any): Promise<unknown>;
        /**
         * @description load dqv data
         * @param commit
         * @param id {String}
         * @param formats {Array}
         * @param locale {String}
         */
        loadDQVData({ commit }: {
            commit: any;
        }, { id, formats, locale }: {
            id: any;
            formats: any;
            locale: any;
        }): Promise<unknown>;
        setLoading({ commit }: {
            commit: any;
        }, isLoading: any): void;
        /**
         * @description Selects distribution for download as (format convertion) service, sets available format options.
         * @param commit
         * @param distribution - Selected distribution.
         * @param selectOptions - Available file formats for convertion
         */
        selectDistributionForDownloadAs({ commit }: {
            commit: any;
        }, { distribution, selectOptions }: {
            distribution: any;
            selectOptions: any;
        }): void;
        /**
        * @description Sets datasetDescription height
        * @param commit
        * @param height
        */
        setDatasetDescriptionHeight({ commit }: {
            commit: any;
        }, height: any): void;
        /**
        * @description Sets dateIncorrect to true if date is not plausible
        * @param commit
        */
        setDateIncorrect({ commit }: {
            commit: any;
        }): void;
    };
    mutations: {
        SET_AVAILABILITY(state: any, availability: any): void;
        SET_POLITICAL_GEOCODING_LEVEL_URL(state: any, politicalGeocodingLevelURI: any): void;
        SET_POLITICAL_GEOCODING_URL(state: any, politicalGeocodingURI: any): void;
        SET_CONTRIBUTOR_ID(state: any, contributorID: any): void;
        SET_LEGAL_BASIS(state: any, legalBasis: any): void;
        SET_QUALITY_PROCESS_URI(state: any, qualityProcessURI: any): void;
        SET_TYPE_DE(state: any, typeDe: any): void;
        SET_REFERENCES(state: any, references: any): void;
        SET_CONTRIBUTER(state: any, contributor: any): void;
        SET_GEOCODING_DESCRIPTION_DE(state: any, geocodingDescriptionDe: any): void;
        SET_ORIGINATOR(state: any, originator: any): void;
        SET_MAINTAINER(state: any, maintainer: any): void;
        SET_ACCESS_RIGHTS(state: any, accessRights: any): void;
        SET_ACCRUAL_PERIODICITY(state: any, accrualPeriodicity: any): void;
        SET_ATTRIBUTES(state: any, attributes: any): void;
        SET_catalog(state: any, catalog: any): void;
        SET_CATEGORIES(state: any, categories: any): void;
        SET_CONFORMS_TO(state: any, conformsTo: any): void;
        SET_CONTACT_POINTS(state: any, contactPoints: any): void;
        SET_COUNTRY(state: any, country: any): void;
        SET_CREATOR(state: any, creator: any): void;
        SET_DATE_INCORRECT(state: any): void;
        SET_DESCRIPTION(state: any, description: any): void;
        SET_DIMENSIONS(state: any, dimensions: any): void;
        SET_DISTRIBUTIONS(state: any, distributions: any): void;
        SET_DISTRIBUTION_FORMATS(state: any, distributionFormats: any): void;
        SET_DOCUMENTATIONS(state: any, documentations: any): void;
        SET_FREQUENCY(state: any, frequency: any): void;
        SET_HAS_QUALITY_ANNOTATIONS(state: any, hasQualityAnnotations: any): void;
        SET_HAS_VERSION(state: any, hasVersion: any): void;
        SET_ID(state: any, id: any): void;
        SET_IDENTIFIERS(state: any, identifiers: any): void;
        SET_ID_NAME(state: any, idName: any): void;
        SET_IS_REFERENCED_BY(state: any, isReferencedBy: any): void;
        SET_IS_VERSION_OF(state: any, isVersionOf: any): void;
        SET_KEYWORDS(state: any, keywords: any): void;
        SET_LANDING_PAGES(state: any, landingPages: any): void;
        SET_LANGUAGES(state: any, languages: any): void;
        SET_LICENCES(state: any, licences: any): void;
        SET_MODIFICATION_DATE(state: any, date: any): void;
        SET_NUM_SERIES(state: any, numSeries: any): void;
        SET_ORIGINAL_LANGUAGE(state: any, originalLanguage: any): void;
        SET_OTHER_IDENTIFIERS(state: any, otherIdentifiers: any): void;
        SET_PAGES(state: any, pages: any): void;
        SET_PROVENANCES(state: any, provenances: any): void;
        SET_PUBLISHER(state: any, publisher: any): void;
        SET_RELATED_RESOURCES(state: any, relatedResources: any): void;
        SET_RELEASE_DATE(state: any, date: any): void;
        SET_RESOURCE(state: any, resource: any): void;
        SET_SOURCES(state: any, sources: any): void;
        SET_SPATIAL(state: any, spatial: any): void;
        SET_SPATIAL_RESOURCE(state: any, spatialResource: any): void;
        SET_STAT_UNIT_MEASURES(state: any, statUnitMeasures: any): void;
        SET_TEMPORAL(state: any, temporal: any): void;
        SET_TRANSLATION_META_DATA(state: any, translationMetaData: any): void;
        SET_TITLE(state: any, title: any): void;
        SET_VERSION_INFO(state: any, versionInfo: any): void;
        SET_VERSION_NOTES(state: any, versionNotes: any): void;
        SET_VISUALISATIONS(state: any, visualisations: any): void;
        SET_WAS_GENERATED_BY(state: any, wasGeneratedBy: any): void;
        SET_SIMILAR_DATASETS_REQUESTED(state: any, similarDatasetsRequested: any): void;
        SET_SIMILAR_DATASETS(state: any, similarDatasets: any): void;
        SET_SD_DESCRIPTION(state: any, payload: any): void;
        SET_SD_TITLE(state: any, payload: any): void;
        SET_SD_DISTRIBUTION_FORMATS(state: any, payload: any): void;
        SET_ACTIVE_NAVIGATION_TAB(state: any, tabIndex: any): void;
        SET_LOADING(state: any, isLoading: any): void;
        SET_QUALITY_DATA_REQUESTED(state: any, qualityDataRequested: any): void;
        SET_QUALITY_DATA(state: any, qualityData: any): void;
        SET_QUALITY_DISTRIBUTION_DATA(state: any, qualityDistributionData: any): void;
        SET_IS_DQV_DATA_REQUESTED(state: any, isDQVDataRequested: any): void;
        SET_IS_DQV_DATA_RDF_AVAILABLE(state: any, isDQVDataRDFAvailable: any): void;
        SET_IS_DQV_DATA_TTL_AVAILABLE(state: any, isDQVDataTTLAvailable: any): void;
        SET_IS_DQV_DATA_N3_AVAILABLE(state: any, isDQVDataN3Available: any): void;
        SET_IS_DQV_DATA_NT_AVAILABLE(state: any, isDQVDataNTAvailable: any): void;
        SET_IS_DQV_DATA_JSONLD_AVAILABLE(state: any, isDQVDataJSONLDAvailable: any): void;
        SET_CATALOG_RECORD(state: any, catalogRecord: any): void;
        SET_ADMS_IDENTIFIERS(state: any, admsIdentifiers: any): void;
        SET_DEADLINE(state: any, deadline: any): void;
        SET_GEOCODING_DESCRIPTION(state: any, geocodingDescription: any): void;
        SET_QUALIFIED_ATTRIBUTIONS(state: any, qualifiedAttributions: any): void;
        SET_QUALIFIED_RELATIONS(state: any, qualifiedRelations: any): void;
        SET_RELATIONS(state: any, relations: any): void;
        SET_SAMPLE(state: any, sample: any): void;
        SET_SPATIAL_RESOLUTION_IN_METERS(state: any, spatialResolutionInMeters: any): void;
        SET_SUBJECT(state: any, subject: any): void;
        SET_TEMPORAL_RESOLUTION(state: any, temporalResolution: any): void;
        SET_THEME(state: any, theme: any): void;
        SET_TYPE(state: any, type: any): void;
        SET_EXTENDET_METADATA(state: any, extendetMetadata: any): void;
        SET_DISTRIBUTION_DOWNLOAD_AS(state: any, distribution: any): void;
        SET_DISTRIBUTION_DOWNLOAD_AS_OPTIONS(state: any, selectOptions: any): void;
        SET_DATASET_DESCRIPTION_HEIGHT(state: any, height: any): void;
        SET_IS_HVD(state: any, isHvd: any): void;
        SET_APPLICABLE_LEGISLATION(state: any, applicableLegislation: any): void;
        SET_HVD_CATEGORY(state: any, hvdCategory: any): void;
    };
    getters: {
        getProperty: (state: any) => (property: any) => any;
        getAvailability: (state: any) => any;
        getPoliticalGeocodingLevelURI: (state: any) => any;
        getPoliticalGeocodingURI: (state: any) => any;
        getContributorID: (state: any) => any;
        getGeocodingDescriptionDe: (state: any) => any;
        getLegalBasis: (state: any) => any;
        getQualityProcessURI: (state: any) => any;
        getTypeDe: (state: any) => any;
        getReferences: (state: any) => any;
        getContributor: (state: any) => any;
        getOriginator: (state: any) => any;
        getMaintainer: (state: any) => any;
        getAccessRights: (state: any) => any;
        getAccrualPeriodicity: (state: any) => any;
        getAdmsIdentifiers: (state: any) => any;
        getAttributes: (state: any) => any;
        getCatalog: (state: any) => any;
        getCategories: (state: any) => any;
        getConformsTo: (state: any) => any;
        getContactPoints: (state: any) => any;
        getCountry: (state: any) => any;
        getCreator: (state: any) => any;
        getDateIncorrect: (state: any) => any;
        getDeadline: (state: any) => any;
        getDescription: (state: any) => any;
        getDimensions: (state: any) => any;
        getDistributions: (state: any) => any;
        getDistributionFormats: (state: any) => any;
        getDocumentations: (state: any) => any;
        getFrequency: (state: any) => any;
        getGeocodingDescription: (state: any) => any;
        getHasQualityAnnotations: (state: any) => any;
        getHasVersion: (state: any) => any;
        getID: (state: any) => any;
        getIdentifiers: (state: any) => any;
        getIdName: (state: any) => any;
        getIsReferencedBy: (state: any) => any;
        getIsVersionOf: (state: any) => any;
        getKeywords: (state: any) => any;
        getSubject: (state: any) => any;
        getLandingPages: (state: any) => any;
        getLanguages: (state: any) => any;
        getLicences: (state: any) => any;
        getModificationDate: (state: any) => any;
        getNumSeries: (state: any) => any;
        getOriginalLanguage: (state: any) => any;
        getOtherIdentifiers: (state: any) => any;
        getPages: (state: any) => any;
        getProvenances: (state: any) => any;
        getPublisher: (state: any) => any;
        getQualifiedAttributions: (state: any) => any;
        getQualifiedRelations: (state: any) => any;
        getRelations: (state: any) => any;
        getRelatedResources: (state: any) => any;
        getReleaseDate: (state: any) => any;
        getSimilarDatasetsRequested: (state: any) => any;
        getSimilarDatasets: (state: any) => any;
        getSample: (state: any) => any;
        getSources: (state: any) => any;
        getSpatial: (state: any) => any;
        getSpatialResource: (state: any) => any;
        getSpatialResolutionInMeters: (state: any) => any;
        getStatUnitMeasures: (state: any) => any;
        getTheme: (state: any) => any;
        getTemporal: (state: any) => any;
        getTemporalResolution: (state: any) => any;
        getTranslationMetaData: (state: any) => any;
        getTitle: (state: any) => any;
        getType: (state: any) => any;
        getResource: (state: any) => any;
        getVersionInfo: (state: any) => any;
        getVersionNotes: (state: any) => any;
        getVisualisations: (state: any) => any;
        getWasGeneratedBy: (state: any) => any;
        getLoading: (state: any) => any;
        getQualityDataRequested: (state: any) => any;
        getQualityData: (state: any) => any;
        getQualityDistributionData: (state: any) => any;
        getIsDQVDataRequested: (state: any) => any;
        getIsDQVDataRDFAvailable: (state: any) => any;
        getIsDQVDataTTLAvailable: (state: any) => any;
        getIsDQVDataN3Available: (state: any) => any;
        getIsDQVDataNTAvailable: (state: any) => any;
        getIsDQVDataJSONLDAvailable: (state: any) => any;
        getCatalogRecord: (state: any) => any;
        getExtendedMetadata: (state: any) => any;
        getDistributionDownloadAs: (state: any) => any;
        getDistributionDownloadAsOptions: (state: any) => any;
        getDatasetDescriptionHeight: (state: any) => any;
        getIsHvd: (state: any) => any;
        getApplicableLegislation: (state: any) => any;
        getHvdCategories: (state: any) => any;
    };
};
export default module;
export interface LoadSimilarDatasetsPayload {
    id: string;
    query?: SimilarDatasetsQuery;
    description?: string;
}
